@@ -88,9 +88,9 @@ class WhisperDecoder(torch.nn.Module):
             # Convert past KV caches (BxNxSxH --> BxSxNxH --> BxSxD) for OpenAI's forward pass
             self_attn_kv_caches, cross_attn_kv_caches = group_past_key_values(past_key_values)
             self_attn_kv_caches = [past_kv.transpose(1, 2) for past_kv in self_attn_kv_caches]
-            self_attn_kv_caches = [past_kv.reshape(past_kv.shape[:2] + (-1,)) for past_kv in self_attn_kv_caches]
+            self_attn_kv_caches = [past_kv.reshape((*past_kv.shape[:2], -1)) for past_kv in self_attn_kv_caches]
             cross_attn_kv_caches = [past_kv.transpose(1, 2) for past_kv in cross_attn_kv_caches]
-            cross_attn_kv_caches = [past_kv.reshape(past_kv.shape[:2] + (-1,)) for past_kv in cross_attn_kv_caches]
+            cross_attn_kv_caches = [past_kv.reshape((*past_kv.shape[:2], -1)) for past_kv in cross_attn_kv_caches]
 
             for idx, block in enumerate(self.model.decoder.blocks):
                 past_kv_cache[block.attn.key] = self_attn_kv_caches[2 * idx]
@@ -145,11 +145,11 @@ class WhisperDecoder(torch.nn.Module):
 
         # Convert present KV caches (BxSxD --> BxSxNxH --> BxNxSxH) after OpenAI's forward pass
         present_self = [
-            present_kv.reshape(present_kv.shape[:2] + (-1, self.head_size)).transpose(1, 2)
+            present_kv.reshape((*present_kv.shape[:2], -1, self.head_size)).transpose(1, 2)
             for present_kv in present_self
         ]
         present_cross = [
-            present_kv.reshape(present_kv.shape[:2] + (-1, self.head_size)).transpose(1, 2)
+            present_kv.reshape((*present_kv.shape[:2], -1, self.head_size)).transpose(1, 2)
             for present_kv in present_cross
         ]
 
@@ -187,7 +187,7 @@ class WhisperDecoder(torch.nn.Module):
                 *list(
                     chain.from_iterable(
                         (f"past_key_self_{i}", f"past_value_self_{i}", f"past_key_cross_{i}", f"past_value_cross_{i}")
-                        for i in range(self.config.num_hidden_layers)
+                        for i in range(self.config.decoder_layers)
                     )
                 ),
             ]
@@ -205,7 +205,7 @@ class WhisperDecoder(torch.nn.Module):
                             f"present_key_cross_{i}",
                             f"present_value_cross_{i}",
                         )
-                        for i in range(self.config.num_hidden_layers)
+                        for i in range(self.config.decoder_layers)
                     )
                 ),
             ]
@@ -214,8 +214,7 @@ class WhisperDecoder(torch.nn.Module):
                 "logits",
                 *list(
                     chain.from_iterable(
-                        (f"present_key_self_{i}", f"present_value_self_{i}")
-                        for i in range(self.config.num_hidden_layers)
+                        (f"present_key_self_{i}", f"present_value_self_{i}") for i in range(self.config.decoder_layers)
                     )
                 ),
             ]
